@@ -55,9 +55,8 @@ LOGGING_DEFAULT_VERBOSITY = 3  # logging.INFO
 # Below the provider, config options are defined.
 PROVIDERS = {
     "lxc": {
-        "supported_operating_systems": ["bionic", "focal"],  # Will not run on any other OSes
+        "supported_operating_systems": ["bionic", "focal", "jammy"],  # Will not run on any other OSes
         "dns-nameserver": "8.8.8.8",
-        "required_host_packages": ["lxd", "lxc", "bridge-utils", "tcpdump", "net-tools", "curl"],  # List of packages required on the host
         "guest_packages": [
             "man",  # List of packages to install on the guest
             "net-tools",
@@ -122,8 +121,8 @@ MACHINE_TYPE_PROVIDER_MAPPING = {
 }
 MACHINE_TYPE_CONFIG_FUNCTION_MAPPING = {
     # For each machine type specify the type specific functions that should be called for it
-    "host": ["disable_{}_ip_forwarding".format(MACHINE_TYPE_PROVIDER_MAPPING["router"])],
-    "router": ["enable_{}_ip_forwarding".format(MACHINE_TYPE_PROVIDER_MAPPING["router"])],
+    "host": [f"disable_{MACHINE_TYPE_PROVIDER_MAPPING['router']}_ip_forwarding"],
+    "router": [f"enable_{MACHINE_TYPE_PROVIDER_MAPPING['router']}_ip_forwarding"],
 }
 VALID_STATUSES = ["start", "stop"]
 VNET_FORCE_ENV_VAR = "VNET_FORCE"
@@ -160,7 +159,7 @@ _{name}_completions() {{
 }}
 complete -F _{name}_completions {name}
 """
-VNET_BASH_COMPLETION_PATH = "/etc/bash_completion.d/{}.bash".format(PYTHON_PACKAGE_NAME)
+VNET_BASH_COMPLETION_PATH = f"/etc/bash_completion.d/{PYTHON_PACKAGE_NAME}.bash"
 
 # LXC specific settings
 LXC_MAX_STATUS_WAIT_ATTEMPTS = 15
